var Enumerations_8H =
[
    [ "FL_ABI_VERSION", "Enumerations_8H.html#a619cd27e13a15a7b1b5ead0932dd3912", null ],
    [ "FL_ALT", "Enumerations_8H.html#a58b1ac5446b292c77043f99558eb07cb", null ],
    [ "FL_Alt_L", "Enumerations_8H.html#a94997ca62280cddce9327c32a256b61a", null ],
    [ "FL_Alt_R", "Enumerations_8H.html#aa06e5417c1a4f46e591950c1a2c28301", null ],
    [ "FL_API_VERSION", "Enumerations_8H.html#a53186dc2831a9786ba70657c771871a7", null ],
    [ "FL_BACK_MOUSE", "Enumerations_8H.html#ac88d21e0a4c27595ab6a8dbfa149afdd", null ],
    [ "FL_BackSpace", "Enumerations_8H.html#a20dc86e7758a88b4d1f06323e2de9896", null ],
    [ "FL_BUTTON", "Enumerations_8H.html#a9c1d8f71cc0a6c159eac4f250ead7687", null ],
    [ "FL_Button", "Enumerations_8H.html#a1df1e46a5113628156ed7b7f995217d0", null ],
    [ "FL_BUTTON1", "Enumerations_8H.html#afe37a4db5e516754bb8963cd341bf415", null ],
    [ "FL_BUTTON2", "Enumerations_8H.html#a1b597a61f3be6323bce3e8c54283b2b3", null ],
    [ "FL_BUTTON3", "Enumerations_8H.html#a9609bc7247660e05194c4e639f84e24e", null ],
    [ "FL_BUTTON4", "Enumerations_8H.html#ac73b2f46df79e0b2421d291c98a226e3", null ],
    [ "FL_BUTTON5", "Enumerations_8H.html#a94f6ac28c07319c6b7b5c7f6be41843d", null ],
    [ "FL_BUTTONS", "Enumerations_8H.html#a6862e0de33aa388ec19a5e0cf3327bb7", null ],
    [ "FL_CAPS_LOCK", "Enumerations_8H.html#add5e55eea768b7bbc0cd25a2455811f0", null ],
    [ "FL_Caps_Lock", "Enumerations_8H.html#a55c0fc2c4fdd81b243e9036b536484e3", null ],
    [ "FL_COMMAND", "Enumerations_8H.html#a5d4011c75b1fe25d9ef36e8ae9e2995c", null ],
    [ "FL_CONTROL", "Enumerations_8H.html#a25fe41b1bd340d52f7970051d8b680bc", null ],
    [ "FL_Control_L", "Enumerations_8H.html#adefca9b73c422d3dadf3fa555d1fb913", null ],
    [ "FL_Control_R", "Enumerations_8H.html#aecba53654154e1c0b22351106636ea79", null ],
    [ "FL_CTRL", "Enumerations_8H.html#a29324ec5ac8c1d87950127d387dc83e8", null ],
    [ "FL_Delete", "Enumerations_8H.html#a323fcf5bab321ec05826a6510a0f1d5a", null ],
    [ "FL_Down", "Enumerations_8H.html#a7b70dabd5fc84d90552442584a0e8b91", null ],
    [ "FL_Eisu", "Enumerations_8H.html#a3c7fc1e50954da94b6d5d2bad4ab3090", null ],
    [ "FL_End", "Enumerations_8H.html#a3278d6209799b821e07369aa5dc140ac", null ],
    [ "FL_Enter", "Enumerations_8H.html#ab4a527fe4d93303976de2fbfec05e19b", null ],
    [ "FL_Escape", "Enumerations_8H.html#a91b983ebe4cd86393e2addb8ab40a326", null ],
    [ "FL_F", "Enumerations_8H.html#ae793aa65307884c2ad99893508d844f2", null ],
    [ "FL_F_Last", "Enumerations_8H.html#a104d0fea5c26197d28294d319dd93af3", null ],
    [ "FL_FORWARD_MOUSE", "Enumerations_8H.html#a2b33ea1af3fd52f316ca4cdc1ab125e7", null ],
    [ "FL_Help", "Enumerations_8H.html#aea65b2b57d3d83d1359df6fc538ff0a9", null ],
    [ "FL_Home", "Enumerations_8H.html#a6fecadc9ecc21f06822c79ced2e45932", null ],
    [ "FL_Insert", "Enumerations_8H.html#ae18bfb47b2b5d5579d227d522a3ce32c", null ],
    [ "FL_Iso_Key", "Enumerations_8H.html#ae56945dcc3ab2a95c59b32ab54bcaabd", null ],
    [ "FL_JIS_Underscore", "Enumerations_8H.html#aef1720c9124147c2aea2b647089b2518", null ],
    [ "FL_Kana", "Enumerations_8H.html#a48db449b0331e8e64b0b494eb194cea5", null ],
    [ "FL_KEY_MASK", "Enumerations_8H.html#aada64e9d1e7f5cecd3629de290b18927", null ],
    [ "FL_KP", "Enumerations_8H.html#a61cc4275772d96a740bef9261cca5760", null ],
    [ "FL_KP_Enter", "Enumerations_8H.html#af6ac160165f8c2747488175321f45a63", null ],
    [ "FL_KP_Last", "Enumerations_8H.html#a14fb705c31fdb8357ae4f3718e20a018", null ],
    [ "FL_Left", "Enumerations_8H.html#afe89caa1c5019809095a6129156f7c5a", null ],
    [ "FL_LEFT_MOUSE", "Enumerations_8H.html#a33b6ebe3faf691660603b03bf4bbeeb8", null ],
    [ "FL_MAJOR_VERSION", "Enumerations_8H.html#a10c923db4d613150c8a3937f9775ccd0", null ],
    [ "FL_Menu", "Enumerations_8H.html#a3a59855ebd5a902cda138956b5ac80bb", null ],
    [ "FL_META", "Enumerations_8H.html#a2c50b1b00111f992d5d49f07c9cee22a", null ],
    [ "FL_Meta_L", "Enumerations_8H.html#acbd392478a5e61f341fe44e24890e213", null ],
    [ "FL_Meta_R", "Enumerations_8H.html#aa21f26e0bc5b3737cf8c0a1b89a200be", null ],
    [ "FL_MIDDLE_MOUSE", "Enumerations_8H.html#a88d6920f2af6a9c2b48be02e5270d097", null ],
    [ "FL_MINOR_VERSION", "Enumerations_8H.html#a165d2781eff3186354a5f5db0528976d", null ],
    [ "FL_NUM_LOCK", "Enumerations_8H.html#af4708895fdb16d3982408fee68ba502b", null ],
    [ "FL_Num_Lock", "Enumerations_8H.html#acf1721eb766274a915bed57acf0e7636", null ],
    [ "FL_Page_Down", "Enumerations_8H.html#ada4d587d21ab710f44043dafba88e110", null ],
    [ "FL_Page_Up", "Enumerations_8H.html#a35834a5c204afffb06374e25734b5c76", null ],
    [ "FL_PATCH_VERSION", "Enumerations_8H.html#afc7b82e6fcfbb451d38e8a0cacde302a", null ],
    [ "FL_Pause", "Enumerations_8H.html#a701e11753a0c38777cb49989de8f0195", null ],
    [ "FL_Print", "Enumerations_8H.html#a4b01dd00e8057590d3778a41920cf80f", null ],
    [ "FL_Right", "Enumerations_8H.html#a45679ed656e6b248319719719e894f13", null ],
    [ "FL_RIGHT_MOUSE", "Enumerations_8H.html#ace3b88a65f6aabab96b0bcc411470c77", null ],
    [ "FL_SCROLL_LOCK", "Enumerations_8H.html#aca94eaafd01b36904a24522c2b2a320a", null ],
    [ "FL_Scroll_Lock", "Enumerations_8H.html#a75315b814f32abe29e7b8d0c43be54d9", null ],
    [ "FL_SHIFT", "Enumerations_8H.html#aa0d93ca1bc8a0c7f84888cdf458f043d", null ],
    [ "FL_Shift_L", "Enumerations_8H.html#ab81acb8d22583da65645c45cb2da1bed", null ],
    [ "FL_Shift_R", "Enumerations_8H.html#a223901295f3b3157bd082a772f20da77", null ],
    [ "FL_SYMBOL_LABEL", "Enumerations_8H.html#a0f3c67869158635bd9bfe3f97a87fc0e", null ],
    [ "FL_Tab", "Enumerations_8H.html#aa6e3e7f377cecb30c77f112ce54c3753", null ],
    [ "FL_Up", "Enumerations_8H.html#a050700391ba0940ca16b0e5dbf4644f0", null ],
    [ "FL_VERSION", "Enumerations_8H.html#a94499c96b5f3ca212d90a2c41f947a67", null ],
    [ "FL_Yen", "Enumerations_8H.html#ac6cd51105d96ffad3571677b0d285770", null ],
    [ "Fl_Align", "Enumerations_8H.html#a44e8bcd1e030e65e4f88cbae64a7c3e3", null ],
    [ "Fl_Color", "Enumerations_8H.html#a8b762953646f8abee866061f1af78a6a", null ],
    [ "Fl_Font", "Enumerations_8H.html#a2ac46d9f082834b969fffe490a03a709", null ],
    [ "Fl_Fontsize", "Enumerations_8H.html#ad58927f5c691454480f7cd28362502f1", null ],
    [ "Fl_Boxtype", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bc", [
      [ "FL_NO_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca48e3b4ff6e390359376e79a8a6bc05c1", null ],
      [ "FL_FLAT_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca6ab2938fe5cb8e5c1ac67da87b6153e6", null ],
      [ "FL_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcab3d71abcebd73ad40dd258f3cdfcfd22", null ],
      [ "FL_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca9374077c9b546ed69f6592c246ba80ad", null ],
      [ "FL_UP_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaaaee8aa58eb2ef122504946791057425", null ],
      [ "FL_DOWN_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcad706a13074d25abb994a0ddd60bc1678", null ],
      [ "FL_THIN_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca1a4ca2c485bc6caa3dea7b54d108b984", null ],
      [ "FL_THIN_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcacce612f8d04d06f2e4f7e5a65d5da264", null ],
      [ "FL_THIN_UP_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcae736190bd31efb08afe14139c1eef7ed", null ],
      [ "FL_THIN_DOWN_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca6787f1f3d4b97df990f759a47aa39ee0", null ],
      [ "FL_ENGRAVED_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcac0235da7fe5bb34f32718b04dee0500d", null ],
      [ "FL_EMBOSSED_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca29a40628cb975d91b49bc71571b64a70", null ],
      [ "FL_ENGRAVED_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca991b75017b74f2238309ac842b0174dd", null ],
      [ "FL_EMBOSSED_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcad69785968dc858de92916ecdf0d766f3", null ],
      [ "FL_BORDER_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca0d2152522f0745a38901b39a2e06ff3c", null ],
      [ "_FL_SHADOW_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca794e5f41a1ce5c827a6d8cbff7a860d1", null ],
      [ "FL_BORDER_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca5be0369168a3e9614098b74c20764807", null ],
      [ "_FL_SHADOW_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca52c4ebde81c5aac67f34e698ff3ae0c5", null ],
      [ "_FL_ROUNDED_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcade712435bbc311ba3a1f8171d955d386", null ],
      [ "_FL_RSHADOW_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca0c607bac437cde8d596d5c7b371a4f0c", null ],
      [ "_FL_ROUNDED_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca5d1f01cb2b2a61f43abceca9532592d6", null ],
      [ "_FL_RFLAT_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca42fe4208bf9be03341196b7ca8be1ec6", null ],
      [ "_FL_ROUND_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcab1ac62a9646083b8f97cb42693182fcf", null ],
      [ "_FL_ROUND_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcae078d9a1dc9517329ab66e2e91331fc0", null ],
      [ "_FL_DIAMOND_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcae54b39c5a9b2226e80cf79c780bc2ab7", null ],
      [ "_FL_DIAMOND_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcad6f366179b00ed97ee6f5aec0ed685bb", null ],
      [ "_FL_OVAL_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaca6602eec2c17112cbf59e52369f4ad2", null ],
      [ "_FL_OSHADOW_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca57e42e5e6a0d69ad87a824439963ec94", null ],
      [ "_FL_OVAL_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca334750b2e12a281df4cbfb49b9d8e897", null ],
      [ "_FL_OFLAT_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca3573f8602d3e763afcedbc4e15c4da2d", null ],
      [ "_FL_PLASTIC_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca0c123448de676c56c5c7ff5f85b9d6e1", null ],
      [ "_FL_PLASTIC_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca869c6e907918a0244b3b9ec69b47d2b1", null ],
      [ "_FL_PLASTIC_UP_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca0e072ecce66fb65691c0cc56ee09525a", null ],
      [ "_FL_PLASTIC_DOWN_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaddbc69513f5613b5073c6288594c1d91", null ],
      [ "_FL_PLASTIC_THIN_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcacc944c3ffd115e3f6308c75cd94eea21", null ],
      [ "_FL_PLASTIC_THIN_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcae5845cab0a2114ae2585787360f877f3", null ],
      [ "_FL_PLASTIC_ROUND_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca1217398c700de4bba61189f95cde1824", null ],
      [ "_FL_PLASTIC_ROUND_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca0f112def153edcea97df6208a2c08358", null ],
      [ "_FL_GTK_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcab22b4715b86414245136a0746f40ba8f", null ],
      [ "_FL_GTK_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca5e85a144179208f2827e8b95bdfbc56c", null ],
      [ "_FL_GTK_UP_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca4986374c8cf8eefe676155ae1828cadc", null ],
      [ "_FL_GTK_DOWN_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcacf1e6a18a81e576870d9262d22720f8c", null ],
      [ "_FL_GTK_THIN_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca71900cb502080854634c3c22f9d6c8b3", null ],
      [ "_FL_GTK_THIN_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaec720ed5ef2c580ca9c1548fe1829d62", null ],
      [ "_FL_GTK_THIN_UP_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca3cbaced50651bf3f3d4d7a4928e26013", null ],
      [ "_FL_GTK_THIN_DOWN_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca447f948f8b8e3eca47f48fa7259b7e73", null ],
      [ "_FL_GTK_ROUND_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca9d606085582d5776295edebc4f30f4f6", null ],
      [ "_FL_GTK_ROUND_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca783a28a1f179ab3267e7ef95ff09f389", null ],
      [ "_FL_GLEAM_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaf97b20fad6220cf0787d744e75735a8a", null ],
      [ "_FL_GLEAM_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca905166e26128b0b63fc59232ae0857b3", null ],
      [ "_FL_GLEAM_UP_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcacd70ec57214ae3ac09a5353a4ddd7ae8", null ],
      [ "_FL_GLEAM_DOWN_FRAME", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca80384b7037a2b048f028380b0277924b", null ],
      [ "_FL_GLEAM_THIN_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcafaf89941b05600b6d4513e387d69cd36", null ],
      [ "_FL_GLEAM_THIN_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca6af9a870d25e3831c945104b0422b0d5", null ],
      [ "_FL_GLEAM_ROUND_UP_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaef18d4d0543d1bb9b08d058e0912e992", null ],
      [ "_FL_GLEAM_ROUND_DOWN_BOX", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaa7cb665d4460e8e5d4d61324a7ae09b1", null ],
      [ "FL_FREE_BOXTYPE", "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcaa9653f0cfb77a72657c6b492cc27480b", null ]
    ] ],
    [ "Fl_Cursor", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0", [
      [ "FL_CURSOR_DEFAULT", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a045f091aae5108f94e912bf5163344dd", null ],
      [ "FL_CURSOR_ARROW", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0af3b7847dd6a361709b45e61c3b2134f7", null ],
      [ "FL_CURSOR_CROSS", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a69ff20b8685ba12b6faef9f7f2565c91", null ],
      [ "FL_CURSOR_WAIT", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a8275eef61a9b77c448f3c53502bee6e0", null ],
      [ "FL_CURSOR_INSERT", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0ab6031998169de52eadfda65d464cbefb", null ],
      [ "FL_CURSOR_HAND", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a1b25ce2668fb1ca7bd85b0ba4cc20ab7", null ],
      [ "FL_CURSOR_HELP", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a9fa6d5e3554972e4996535a5bff6260c", null ],
      [ "FL_CURSOR_MOVE", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a0429eefdb7ef6bbfacbbd389b5bd891e", null ],
      [ "FL_CURSOR_NS", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0ab47413e34d7d268488a279b9f93d694b", null ],
      [ "FL_CURSOR_WE", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a1f084eec70809a1edc89031d97d754f6", null ],
      [ "FL_CURSOR_NWSE", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a886c85d5b062a34fa1cfac16e7896526", null ],
      [ "FL_CURSOR_NESW", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0abf1958a458f8e6c99cc4eae28856ecbe", null ],
      [ "FL_CURSOR_N", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0afc216f1424895e8a3ff70ee4d396a359", null ],
      [ "FL_CURSOR_NE", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0ac6b21e75adf3bd782e3c4affe992ba33", null ],
      [ "FL_CURSOR_E", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a655675f4a5c1009798c4688811f7aef8", null ],
      [ "FL_CURSOR_SE", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a20e02baa5891403ea99e770525dcb906", null ],
      [ "FL_CURSOR_S", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0ae346bec5544ac09f2ac846f37fc802dd", null ],
      [ "FL_CURSOR_SW", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0ac556babff2b1387a1139f07c7361a8f5", null ],
      [ "FL_CURSOR_W", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a3e71103dc03ff53a2a53be5e7e4b19eb", null ],
      [ "FL_CURSOR_NW", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a414ffb070f3fbcd0a97dafdaa6b718f7", null ],
      [ "FL_CURSOR_NONE", "Enumerations_8H.html#a72bde974edc7926b1217dd51b8c7e8e0a4bc466fe5135272bccedd6b8f97156c7", null ]
    ] ],
    [ "Fl_Damage", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146d", [
      [ "FL_DAMAGE_CHILD", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146dad0cb406be09a7f40cbeadc398f63ce1e", null ],
      [ "FL_DAMAGE_EXPOSE", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146da1d579fbc483892ba72a416d3ff14a942", null ],
      [ "FL_DAMAGE_SCROLL", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146dafdc77ddf81c29ac03996cd6dbdeb02c8", null ],
      [ "FL_DAMAGE_OVERLAY", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146daa57c8339e2fd951d8736ebf8167c0967", null ],
      [ "FL_DAMAGE_USER1", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146da40a87a162ccaca25231a098773c9871c", null ],
      [ "FL_DAMAGE_USER2", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146da1c384fa72a294193f806db5d62d317bc", null ],
      [ "FL_DAMAGE_ALL", "Enumerations_8H.html#a9a20351f841109b3d861e0c1248d146dae2ea13879a0e90540108be65c5bc8e4b", null ]
    ] ],
    [ "Fl_Event", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3", [
      [ "FL_NO_EVENT", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aee4e8cf3108b1a47c67231451d39042f", null ],
      [ "FL_PUSH", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a44972d76423f3e380ae12c36827944e3", null ],
      [ "FL_RELEASE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a5949b5ff170a8236d2745eddb1e9fd9a", null ],
      [ "FL_ENTER", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a29b256ac93d443dd33a8c610c24e7af5", null ],
      [ "FL_LEAVE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aa776cf3129e97140c88a062881a2d29a", null ],
      [ "FL_DRAG", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aaad5c7b2302d7bfe6c6d37b50b4c70f0", null ],
      [ "FL_FOCUS", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3adaac2a187beb309443d668a20a59986b", null ],
      [ "FL_UNFOCUS", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a7d2e5eb9247b1927ba5cc26dc82acaf3", null ],
      [ "FL_KEYDOWN", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a1d132318f4c72305fd1babbbc4dbeb1a", null ],
      [ "FL_KEYBOARD", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a1387c0430ec873aa44704954a369143b", null ],
      [ "FL_KEYUP", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3ab0e1a75a36767b878915e59e5f9e3be8", null ],
      [ "FL_CLOSE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a42828f08af2b2191bbc60e113ec08f01", null ],
      [ "FL_MOVE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3acd57cae091eb27c9a52c446bdd0c164d", null ],
      [ "FL_SHORTCUT", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a6161f0e91cc6b2947200323e3bda8156", null ],
      [ "FL_DEACTIVATE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3ad9fd8e3ac1c8c3533f73205e450af9d3", null ],
      [ "FL_ACTIVATE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a50072421b5f3d1911d937f668d8b695d", null ],
      [ "FL_HIDE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aed9d7c8fbb9dac1e16f762195f00d5d6", null ],
      [ "FL_SHOW", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a9edbfd236c9ea348dcaae935a76bd885", null ],
      [ "FL_PASTE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a5e811b9d703e6f66cfdca256ecfbb0cf", null ],
      [ "FL_SELECTIONCLEAR", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aa72e0701dedd76bbc47ec50c99437537", null ],
      [ "FL_MOUSEWHEEL", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3ad5f7dd40377c51d5795cd53ded3d4bef", null ],
      [ "FL_DND_ENTER", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3af4f28b5ef9ec051e4a4d9e19a16370b8", null ],
      [ "FL_DND_DRAG", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aadfedcde7415286c752ba427f0e8626f", null ],
      [ "FL_DND_LEAVE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a03bdb8df3578915e1d0829cc048d855e", null ],
      [ "FL_DND_RELEASE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a80deb55dbc048b83dc154c11c658b7d6", null ],
      [ "FL_SCREEN_CONFIGURATION_CHANGED", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a00ef761326ea0a098d36a5391c9d99e1", null ],
      [ "FL_FULLSCREEN", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3ad49e4d1deb4c1fe555dcef9be107c21f", null ],
      [ "FL_ZOOM_GESTURE", "Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a7f85bd3003a4a893b08c919e1936f960", null ]
    ] ],
    [ "Fl_Labeltype", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61b", [
      [ "FL_NORMAL_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61ba81ddb843b9f43f73446ea7d6d7d8cc84", null ],
      [ "FL_NO_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61bac7e2de1d28830fe78743126eebcbe13b", null ],
      [ "_FL_SHADOW_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61ba42d8fbe615129db500beeda794a8b85d", null ],
      [ "_FL_ENGRAVED_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61ba8137ee7579c41cf0efca9b8b5bd7a98a", null ],
      [ "_FL_EMBOSSED_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61ba1b9e2cb1deac2a46a0c48fc53cef2209", null ],
      [ "_FL_MULTI_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61bab1871e45f37d1f355e94314ab9cf19fa", null ],
      [ "_FL_ICON_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61baf92e61ad9e90f0caed893af403eb2440", null ],
      [ "_FL_IMAGE_LABEL", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61ba4eacee23d77760ec01a7491a53840006", null ],
      [ "FL_FREE_LABELTYPE", "Enumerations_8H.html#ad5774781d33328b82990ff9e25dfd61bae8d04c6d9eb936bed041d8a61eed223c", null ]
    ] ],
    [ "Fl_Mode", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0", [
      [ "FL_RGB", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a109b723978c5a645aeee20cf1b4c3667", null ],
      [ "FL_INDEX", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a90f0c69fd007454b2ff005387fc43efd", null ],
      [ "FL_SINGLE", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a3efd17ba11bffba831cdf03f2e7a4ccc", null ],
      [ "FL_DOUBLE", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a77de126af21a8b581c890c59e0e0a88f", null ],
      [ "FL_ACCUM", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0adf831f7fa1fd333a884047fdcdae6a16", null ],
      [ "FL_ALPHA", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a02924f38d737cfd29580a8d251876205", null ],
      [ "FL_DEPTH", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a310da601ea0b8d67932d980a84543071", null ],
      [ "FL_STENCIL", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a031307414530eed8e6f8910123c2b812", null ],
      [ "FL_RGB8", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0adcf149bdd69c0ce3f034d6aa9d878b18", null ],
      [ "FL_MULTISAMPLE", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a03f76720b861e119423cc37b5506af82", null ],
      [ "FL_STEREO", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a1e01e6a4f9825b9b91703a4411e52827", null ],
      [ "FL_FAKE_SINGLE", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a48d1ab44872ef5093795c616522bde1e", null ],
      [ "FL_OPENGL3", "Enumerations_8H.html#aae982ff3b1a082b1a512b216b98061e0a7807760f3ba86c2c4911ed13cde862d3", null ]
    ] ],
    [ "Fl_When", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665", [
      [ "FL_WHEN_NEVER", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665adfa635a2abba2b9d9fbfc10294d87f3c", null ],
      [ "FL_WHEN_CHANGED", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665ae504aaa4de36a9ff606530956c68887a", null ],
      [ "FL_WHEN_NOT_CHANGED", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665ac5385d8670aedf159e0271731fceab85", null ],
      [ "FL_WHEN_RELEASE", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665afbd4ae9061c3cd4bc9b4aa94fcb8137a", null ],
      [ "FL_WHEN_RELEASE_ALWAYS", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665a178d65ff4c14dbe7a4c3a430734eb677", null ],
      [ "FL_WHEN_ENTER_KEY", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665a07b6d76bf4ca08fc78b646d6d5959f09", null ],
      [ "FL_WHEN_ENTER_KEY_ALWAYS", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665aa62e296209f00c30b7d4a09a7e5b169b", null ],
      [ "FL_WHEN_ENTER_KEY_CHANGED", "Enumerations_8H.html#adaaa8b52b78abf3ccce4787b112e6665a1996a72752f22036d01e9b94d3e92f1a", null ]
    ] ],
    [ "fl_box", "Enumerations_8H.html#a9296d2ab39525c54c84ce392b9f06ebe", null ],
    [ "fl_color_average", "group__fl__attributes.html#gaad12eb8d8495f7238bd3d0960f264be8", null ],
    [ "fl_color_cube", "Enumerations_8H.html#a2f613709d1c9444f9f03e7c0349223f3", null ],
    [ "fl_contrast", "group__fl__attributes.html#ga54d75920c0484916cd6b2101937ec5ff", null ],
    [ "fl_darker", "Enumerations_8H.html#a88fd2733842cb5d287650bcf160f2531", null ],
    [ "fl_down", "Enumerations_8H.html#a6aa37e8d5c59e2e4f40848f9b2b93a70", null ],
    [ "fl_frame", "Enumerations_8H.html#a06e61a87a8570f7debc751a1e2f5340f", null ],
    [ "fl_gray_ramp", "Enumerations_8H.html#a6045423248a367d4d3885109f18e0bd9", null ],
    [ "fl_inactive", "group__fl__attributes.html#ga1480e5317934bbd43d401f00ab3eba8b", null ],
    [ "fl_lighter", "Enumerations_8H.html#affef7da8b67f0b735d5dcb9ebe60e17d", null ],
    [ "fl_rgb_color", "Enumerations_8H.html#af26a6486e65decd723fbe5c1f43deb0b", null ],
    [ "fl_rgb_color", "Enumerations_8H.html#a7c5acc4633fbab7016bce2fb69046494", null ],
    [ "FL_ALIGN_BOTTOM", "Enumerations_8H.html#a1ea3fa817f07b80dced581f58de842ae", null ],
    [ "FL_ALIGN_CENTER", "Enumerations_8H.html#a427f1ce53c37478a59f64bec4a2e2241", null ],
    [ "FL_ALIGN_CLIP", "Enumerations_8H.html#a527e2db976be1a8508c226b4ca54eaa7", null ],
    [ "FL_ALIGN_IMAGE_BACKDROP", "Enumerations_8H.html#a1aaa3dafad6349ff2e36c2b94694ddc4", null ],
    [ "FL_ALIGN_IMAGE_NEXT_TO_TEXT", "Enumerations_8H.html#ae01274c851cadd0ae5f7c5b519f0245a", null ],
    [ "FL_ALIGN_IMAGE_OVER_TEXT", "Enumerations_8H.html#a44f5822e9594733418ec39f7c061d2d7", null ],
    [ "FL_ALIGN_INSIDE", "Enumerations_8H.html#ade440c90fc9c2495fdf04c9cb34fba34", null ],
    [ "FL_ALIGN_LEFT", "Enumerations_8H.html#aee67f09771b16bc5da1f1ee860681be5", null ],
    [ "FL_ALIGN_RIGHT", "Enumerations_8H.html#a16646615fa4863fae6f7975b36c3987e", null ],
    [ "FL_ALIGN_TEXT_NEXT_TO_IMAGE", "Enumerations_8H.html#a6500fc80f0febfd4bd87025a3df5cff6", null ],
    [ "FL_ALIGN_TEXT_OVER_IMAGE", "Enumerations_8H.html#ab6413c20d509320c27f498ef2d65ce3f", null ],
    [ "FL_ALIGN_TOP", "Enumerations_8H.html#a62b22e4022b39d90a2d3962ae144f2e8", null ],
    [ "FL_ALIGN_WRAP", "Enumerations_8H.html#ad824439377f8aa436e39c5d12d9fb26f", null ],
    [ "FL_BACKGROUND2_COLOR", "Enumerations_8H.html#a5c5704ed2ec5eb9c964d6dcb51474055", null ],
    [ "FL_BOLD", "Enumerations_8H.html#a5b4c5d04c411d4c086101f5b955c556a", null ],
    [ "FL_BOLD_ITALIC", "Enumerations_8H.html#a45f68cc36d155e45c4bea90a486a5e13", null ],
    [ "FL_COURIER", "Enumerations_8H.html#ae722fe030bd9bcba33f045098295579d", null ],
    [ "FL_COURIER_BOLD", "Enumerations_8H.html#a311479135f085f16d2a7432af8f482eb", null ],
    [ "FL_COURIER_BOLD_ITALIC", "Enumerations_8H.html#a812b67c693f4809c778d39d77d15bb90", null ],
    [ "FL_COURIER_ITALIC", "Enumerations_8H.html#afc9d9ab48f1f9ff634c30fd2af4bb8ad", null ],
    [ "FL_FOREGROUND_COLOR", "Enumerations_8H.html#a8c67b74501f259f9bcfbf55415cfc162", null ],
    [ "FL_FREE_FONT", "Enumerations_8H.html#abdd37d3dbabf724c9bb0438916a6db2f", null ],
    [ "FL_HELVETICA", "Enumerations_8H.html#a74d2c443f7ab53a6ce5d4ca0c7461bc9", null ],
    [ "FL_HELVETICA_BOLD", "Enumerations_8H.html#ae52b5d98292bf142ea1c7468d7d732cd", null ],
    [ "FL_HELVETICA_BOLD_ITALIC", "Enumerations_8H.html#a925bd586f4c991776b48827818c16707", null ],
    [ "FL_HELVETICA_ITALIC", "Enumerations_8H.html#a384a459d931aaf8140cd84034a5887dd", null ],
    [ "FL_INACTIVE_COLOR", "Enumerations_8H.html#a6501a998c459a5a117784f8c95a83a41", null ],
    [ "FL_ITALIC", "Enumerations_8H.html#abdc8e2cce930b923594df50760299776", null ],
    [ "FL_NORMAL_SIZE", "Enumerations_8H.html#a200c616eb9f1a5d32a0b79847cef8cc8", null ],
    [ "FL_SCREEN", "Enumerations_8H.html#a54136abc1d834eea22975288d5393ebe", null ],
    [ "FL_SCREEN_BOLD", "Enumerations_8H.html#abcd5288ae4c97da3a85ee095cafb44e0", null ],
    [ "FL_SELECTION_COLOR", "Enumerations_8H.html#a331e6d52a8f08e7d9bafd9cc8341cd9f", null ],
    [ "FL_SYMBOL", "Enumerations_8H.html#a2b2df61e619d3e6658b2fbb5cef5dc8e", null ],
    [ "FL_TIMES", "Enumerations_8H.html#a35fe64b07a0f270411dfbcbcc109033c", null ],
    [ "FL_TIMES_BOLD", "Enumerations_8H.html#a41f70582714a3bd83fa3a32fb14b239f", null ],
    [ "FL_TIMES_BOLD_ITALIC", "Enumerations_8H.html#a1315245575ff4617c3dbee5b42649212", null ],
    [ "FL_TIMES_ITALIC", "Enumerations_8H.html#a881c8b4f190bccdf48d2df42ca921586", null ],
    [ "FL_ZAPF_DINGBATS", "Enumerations_8H.html#a30b0e07f3e71e9942b7e30ebfcc73d37", null ]
];